.. _index:

===================
Kotti Documentation
===================

Kotti is a user-friendly, nimble and extensible web content management system,
based on Pyramid and SQLAlchemy.

If you are a user of a Kotti system, and either found this page through
browsing or searching, or were referred here, you will want to go directly to
the `Kotti User Manual`_ The documentation below, ``First Steps``, ``Topics``,
and so on, are for developers of Kotti.

.. _Kotti User Manual: http://kotti-user-manual.readthedocs.org/

First Steps
-----------

.. toctree::
    :maxdepth: 1

    first_steps/overview
    first_steps/installation
    first_steps/tut-1
    first_steps/tut-2
    first_steps/tut-3

Topics
------

.. toctree::
    :maxdepth: 1

    developing/developer-manual
    developing/security
    developing/configuration
    developing/testing
    developing/translations
    developing/deployment

-   Advanced topics

    .. toctree::
        :maxdepth: 1

        developing/as-a-library
        developing/close-for-anonymous
        developing/default-views
        developing/events
        developing/frontpage-different-template
        developing/images
        developing/static-resource-management
        developing/understanding-kotti-startup

API
---

.. toctree::
    :maxdepth: 1

    API documentation <api/index>

Kotti User Manual
-----------------

The `Kotti User Manual`_ is rendered and hosted on readthedocs.org.

Developers, please see the :ref:`developer_manual` for instructions on
contributing to the user manual.

.. _Kotti User Manual: http://kotti-user-manual.readthedocs.org/

Changes
-------

.. toctree::
    :maxdepth: 1

    Complete list of changes since Kotti 0.2a1 <changes>
